summaryrefslogtreecommitdiffstats
path: root/rpc/rpc-transport
diff options
context:
space:
mode:
Diffstat (limited to 'rpc/rpc-transport')
-rw-r--r--rpc/rpc-transport/rdma/src/rdma.c6
-rw-r--r--rpc/rpc-transport/socket/src/socket.c2
2 files changed, 4 insertions, 4 deletions
diff --git a/rpc/rpc-transport/socket/src/socket.c b/rpc/rpc-transport/socket/src/socket.c
index 87430d22aae..395bf738427 100644
--- a/rpc/rpc-transport/socket/src/socket.c
+++ b/rpc/rpc-transport/socket/src/socket.c
@@ -1382,7 +1382,7 @@ __socket_read_frag (rpc_transport_t *this)
} else if (priv->incoming.msg_type == GF_UNIVERSAL_ANSWER) {
gf_log ("rpc", GF_LOG_ERROR,
"older version of protocol/process trying to "
- "connect from %s. use newer verison on that node",
+ "connect from %s. use newer version on that node",
this->peerinfo.identifier);
} else {
gf_log ("rpc", GF_LOG_ERROR,
diff --git a/rpc/rpc-transport/rdma/src/rdma.c b/rpc/rpc-transport/rdma/src/rdma.c
index 177730f65a0..7d2bfc0ad74 100644
--- a/rpc/rpc-transport/rdma/src/rdma.c
+++ b/rpc/rpc-transport/rdma/src/rdma.c
@@ -2866,14 +2866,14 @@ rdma_decode_header (rdma_peer_t *peer, rdma_post_t *post,
case RDMA_MSGP:
gf_log (RDMA_LOG_NAME, GF_LOG_ERROR,
"rdma msg of msg-type RDMA_MSGP should not have been "
- "recieved");
+ "received");
ret = -1;
break;
case RDMA_DONE:
gf_log (RDMA_LOG_NAME, GF_LOG_ERROR,
"rdma msg of msg-type RDMA_DONE should not have been "
- "recieved");
+ "received");
ret = -1;
break;
@@ -3042,7 +3042,7 @@ rdma_pollin_notify (rdma_peer_t *peer, rdma_post_t *post)
}
/* handling the case where both hdr and payload of
* GF_FOP_READ_CBK were recieved in a single iobuf
* because of server sending entire msg as inline without
* doing rdma writes.
*/
@@ -3042,7 +3042,7 @@ rdma_pollin_notify (rdma_peer_t *peer, rdma_post_t *post)
}
/* handling the case where both hdr and payload of
- * GF_FOP_READ_CBK were recieved in a single iobuf
+ * GF_FOP_READ_CBK were received in a single iobuf
* because of server sending entire msg as inline without
* doing rdma writes.